Add an option to disable lib2to3

lib2to3 is a library to convert Python 2.x code to Python 3.x. As
such, it is probably not very useful on embedded system targets.

Signed-off-by: Thomas Petazzoni <thomas.petazzoni@free-electrons.com>

---
 Makefile.pre.in |   24 +++++++++++++++++-------
 configure.in    |    6 ++++++
 setup.py        |    5 +++--
 3 files changed, 26 insertions(+), 9 deletions(-)

Index: Python-2.7.1/Makefile.pre.in
===================================================================
--- Python-2.7.1.orig/Makefile.pre.in
+++ Python-2.7.1/Makefile.pre.in
@@ -856,9 +856,7 @@
 		encodings compiler hotshot \
 		email email/mime \
 		json \
-		sqlite3 \
 		logging bsddb csv importlib wsgiref \
-		lib2to3 lib2to3/fixes lib2to3/pgen2 \
 		ctypes ctypes/macholib idlelib idlelib/Icons \
 		distutils distutils/command $(XMLLIBSUBDIRS) \
 		multiprocessing multiprocessing/dummy \
@@ -872,12 +870,7 @@
 		test/decimaltestdata test/xmltestdata 	\
 		test/tracedmodules   			\
 		email/test email/test/data		\
-		sqlite3/test				\
 		bsddb/test				\
-		lib2to3/tests				\
-		lib2to3/tests/data			\
-		lib2to3/tests/data/fixers		\
-		lib2to3/tests/data/fixers/myfixes	\
 		ctypes/test distutils/tests		\
 		unittest/test
 endif
@@ -886,6 +879,23 @@
 LIBSUBDIRS += pydoc_data
 endif
 
+ifeq (@LIB2TO3@,yes)
+LIBSUBDIRS += lib2to3 lib2to3/fixes lib2to3/pgen2
+ifeq (@TEST_MODULES@,yes)
+LIBSUBDIRS += 	lib2to3/tests				\
+		lib2to3/tests/data			\
+		lib2to3/tests/data/fixers		\
+		lib2to3/tests/data/fixers/myfixes
+endif
+endif
+
+ifeq (@SQLITE3@,yes)
+LIBSUBDIRS += sqlite3
+ifeq (@TEST_MODULES@,yes)
+LIBSUBDIRS += sqlite3/test
+endif
+endif
+
 libinstall:	build_all $(srcdir)/Lib/$(PLATDIR)
 	@for i in $(SCRIPTDIR) $(LIBDEST); \
 	do \
Index: Python-2.7.1/configure.in
===================================================================
--- Python-2.7.1.orig/configure.in
+++ Python-2.7.1/configure.in
@@ -2404,6 +2404,12 @@
 	AS_HELP_STRING([--disable-test-modules], [disable test modules]),
 	[ TEST_MODULES="${enableval}" ], [ TEST_MODULES=yes ])
 
+AC_SUBST(LIB2TO3)
+
+AC_ARG_ENABLE(lib2to3,
+	AS_HELP_STRING([--disable-lib2to3], [disable lib2to3]),
+	[ LIB2TO3="${enableval}" ], [ LIB2TO3=yes ])
+
 # Check for enable-ipv6
 AH_TEMPLATE(ENABLE_IPV6, [Define if --enable-ipv6 is specified])
 AC_MSG_CHECKING([if --enable-ipv6 is specified])
Index: Python-2.7.1/setup.py
===================================================================
--- Python-2.7.1.orig/setup.py
+++ Python-2.7.1/setup.py
@@ -2073,10 +2073,11 @@
     import warnings
     warnings.filterwarnings("ignore",category=DeprecationWarning)
 
-    scripts = ['Tools/scripts/idle', 'Tools/scripts/2to3',
-               'Lib/smtpd.py']
+    scripts = ['Tools/scripts/idle', 'Lib/smtpd.py']
     if not '--disable-pydoc' in sysconfig.get_config_var("CONFIG_ARGS"):
         scripts += [ 'Tools/scripts/pydoc' ]
+    if not '--disable-lib2to3' in sysconfig.get_config_var("CONFIG_ARGS"):
+        scripts += [ 'Tools/scripts/2to3' ]
 
     setup(# PyPI Metadata (PEP 301)
           name = "Python",
